smartcard.AbstractCardRequest.AbstractCardRequest

# ``smartcard`.`AbstractCardRequest`.`AbstractCardRequest``

class documentation

`class AbstractCardRequest(object):`

Known subclasses: `smartcard.pcsc.PCSCCardRequest.PCSCCardRequest`

View In Hierarchy

The base class for xxxCardRequest classes.

A CardRequest is used for waitForCard() invocations and specifies what kind of smart card an application is waited for.

Method | `__init__` | Construct new CardRequest.
Method | `getReaders` | Returns the list or readers on which to wait for cards.
Method | `waitforcard` | Wait for card insertion and returns a card service.
Method | `waitforcardevent` | Wait for card insertion or removal.
Instance Variable | `cardServiceClass` | Undocumented
Instance Variable | `cardType` | Undocumented
Instance Variable | `newcardonly` | Undocumented
Instance Variable | `readersAsked` | Undocumented
Instance Variable | `timeout` | Undocumented

def __init__(self, newcardonly=False, readers=None, cardType=None, cardServiceClass=None, timeout=1):
overridden in `smartcard.pcsc.PCSCCardRequest.PCSCCardRequest`

Construct new CardRequest.

Parameters
newcardonly | if True, request a new card; default is False, i.e. accepts cards already inserted
readers | the list of readers to consider for requesting a card; default is to consider all readers
cardType | the `smartcard.CardType.CardType` to wait for; default is `smartcard.CardType.AnyCardType`, i.e. the request will succeed with any card
cardServiceClass | the specific card service class to create and bind to the card;default is to create and bind a `smartcard.PassThruCardService`
timeout | the time in seconds we are ready to wait for connecting to the requested card. default is to wait one second; to wait forever, set timeout to None

def getReaders(self):

Returns the list or readers on which to wait for cards.

def waitforcard(self):
overridden in `smartcard.pcsc.PCSCCardRequest.PCSCCardRequest`

Wait for card insertion and returns a card service.

def waitforcardevent(self):
overridden in `smartcard.pcsc.PCSCCardRequest.PCSCCardRequest`

Wait for card insertion or removal.

cardServiceClass =

Undocumented

cardType =

Undocumented

newcardonly =

Undocumented

readersAsked =

Undocumented

timeout =
overridden in `smartcard.pcsc.PCSCCardRequest.PCSCCardRequest`

Undocumented